# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'FleetInventoryLog',
    'FleetOperationLog',
    'GetFleetAdvancedFeatureConfigurationAdvancedUsageTrackingResult',
    'GetFleetAdvancedFeatureConfigurationCryptoEventAnalysisResult',
    'GetFleetAdvancedFeatureConfigurationCryptoEventAnalysisSummarizedEventsLogResult',
    'GetFleetAdvancedFeatureConfigurationJfrRecordingResult',
    'GetFleetAdvancedFeatureConfigurationLcmResult',
    'GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionResult',
    'GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingResult',
    'GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingCertpathResult',
    'GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingJarResult',
    'GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingTlResult',
    'GetFleetBlocklistsFilterResult',
    'GetFleetBlocklistsItemResult',
    'GetFleetBlocklistsItemTargetResult',
    'GetFleetCryptoAnalysisResultsCryptoAnalysisResultCollectionResult',
    'GetFleetCryptoAnalysisResultsCryptoAnalysisResultCollectionItemResult',
    'GetFleetCryptoAnalysisResultsFilterResult',
    'GetFleetInventoryLogResult',
    'GetFleetOperationLogResult',
    'GetFleetsFilterResult',
    'GetFleetsFleetCollectionResult',
    'GetFleetsFleetCollectionItemResult',
    'GetFleetsFleetCollectionItemInventoryLogResult',
    'GetFleetsFleetCollectionItemOperationLogResult',
    'GetInstallationSiteItemResult',
    'GetInstallationSiteItemBlocklistResult',
    'GetInstallationSiteItemJreResult',
    'GetInstallationSiteItemOperatingSystemResult',
    'GetInstallationSitesFilterResult',
    'GetInstallationSitesInstallationSiteCollectionResult',
    'GetInstallationSitesInstallationSiteCollectionItemResult',
    'GetInstallationSitesInstallationSiteCollectionItemItemResult',
    'GetInstallationSitesInstallationSiteCollectionItemItemBlocklistResult',
    'GetInstallationSitesInstallationSiteCollectionItemItemJreResult',
    'GetInstallationSitesInstallationSiteCollectionItemItemOperatingSystemResult',
    'GetJavaFamiliesFilterResult',
    'GetJavaFamiliesJavaFamilyCollectionResult',
    'GetJavaFamiliesJavaFamilyCollectionItemResult',
    'GetJavaReleaseArtifactResult',
    'GetJavaReleaseFamilyDetailResult',
    'GetJavaReleaseLicenseDetailResult',
    'GetJavaReleasesFilterResult',
    'GetJavaReleasesJavaReleaseCollectionResult',
    'GetJavaReleasesJavaReleaseCollectionItemResult',
    'GetJavaReleasesJavaReleaseCollectionItemArtifactResult',
    'GetJavaReleasesJavaReleaseCollectionItemFamilyDetailResult',
    'GetJavaReleasesJavaReleaseCollectionItemLicenseDetailResult',
    'GetListJreUsageItemResult',
    'GetListJreUsageItemOperatingSystemResult',
]

@pulumi.output_type
class FleetInventoryLog(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "logGroupId":
            suggest = "log_group_id"
        elif key == "logId":
            suggest = "log_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FleetInventoryLog. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FleetInventoryLog.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FleetInventoryLog.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 log_group_id: str,
                 log_id: str):
        """
        :param str log_group_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        :param str log_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "log_group_id", log_group_id)
        pulumi.set(__self__, "log_id", log_id)

    @property
    @pulumi.getter(name="logGroupId")
    def log_group_id(self) -> str:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        """
        return pulumi.get(self, "log_group_id")

    @property
    @pulumi.getter(name="logId")
    def log_id(self) -> str:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "log_id")


@pulumi.output_type
class FleetOperationLog(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "logGroupId":
            suggest = "log_group_id"
        elif key == "logId":
            suggest = "log_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FleetOperationLog. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FleetOperationLog.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FleetOperationLog.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 log_group_id: str,
                 log_id: str):
        """
        :param str log_group_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        :param str log_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "log_group_id", log_group_id)
        pulumi.set(__self__, "log_id", log_id)

    @property
    @pulumi.getter(name="logGroupId")
    def log_group_id(self) -> str:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        """
        return pulumi.get(self, "log_group_id")

    @property
    @pulumi.getter(name="logId")
    def log_id(self) -> str:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "log_id")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationAdvancedUsageTrackingResult(dict):
    def __init__(__self__, *,
                 is_enabled: bool):
        """
        :param bool is_enabled: Lcm flag to store enabled or disabled status
        """
        pulumi.set(__self__, "is_enabled", is_enabled)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> bool:
        """
        Lcm flag to store enabled or disabled status
        """
        return pulumi.get(self, "is_enabled")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationCryptoEventAnalysisResult(dict):
    def __init__(__self__, *,
                 is_enabled: bool,
                 summarized_events_logs: Sequence['outputs.GetFleetAdvancedFeatureConfigurationCryptoEventAnalysisSummarizedEventsLogResult']):
        """
        :param bool is_enabled: Lcm flag to store enabled or disabled status
        :param Sequence['GetFleetAdvancedFeatureConfigurationCryptoEventAnalysisSummarizedEventsLogArgs'] summarized_events_logs: Summarized events log for advanced feature.
        """
        pulumi.set(__self__, "is_enabled", is_enabled)
        pulumi.set(__self__, "summarized_events_logs", summarized_events_logs)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> bool:
        """
        Lcm flag to store enabled or disabled status
        """
        return pulumi.get(self, "is_enabled")

    @property
    @pulumi.getter(name="summarizedEventsLogs")
    def summarized_events_logs(self) -> Sequence['outputs.GetFleetAdvancedFeatureConfigurationCryptoEventAnalysisSummarizedEventsLogResult']:
        """
        Summarized events log for advanced feature.
        """
        return pulumi.get(self, "summarized_events_logs")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationCryptoEventAnalysisSummarizedEventsLogResult(dict):
    def __init__(__self__, *,
                 log_group_id: str,
                 log_id: str):
        """
        :param str log_group_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        :param str log_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        pulumi.set(__self__, "log_group_id", log_group_id)
        pulumi.set(__self__, "log_id", log_id)

    @property
    @pulumi.getter(name="logGroupId")
    def log_group_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        """
        return pulumi.get(self, "log_group_id")

    @property
    @pulumi.getter(name="logId")
    def log_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        return pulumi.get(self, "log_id")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationJfrRecordingResult(dict):
    def __init__(__self__, *,
                 is_enabled: bool):
        """
        :param bool is_enabled: Lcm flag to store enabled or disabled status
        """
        pulumi.set(__self__, "is_enabled", is_enabled)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> bool:
        """
        Lcm flag to store enabled or disabled status
        """
        return pulumi.get(self, "is_enabled")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationLcmResult(dict):
    def __init__(__self__, *,
                 is_enabled: bool,
                 post_installation_actions: Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionResult']):
        """
        :param bool is_enabled: Lcm flag to store enabled or disabled status
        :param Sequence['GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionArgs'] post_installation_actions: List of available post actions you can execute after the successful Java installation.
        """
        pulumi.set(__self__, "is_enabled", is_enabled)
        pulumi.set(__self__, "post_installation_actions", post_installation_actions)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> bool:
        """
        Lcm flag to store enabled or disabled status
        """
        return pulumi.get(self, "is_enabled")

    @property
    @pulumi.getter(name="postInstallationActions")
    def post_installation_actions(self) -> Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionResult']:
        """
        List of available post actions you can execute after the successful Java installation.
        """
        return pulumi.get(self, "post_installation_actions")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionResult(dict):
    def __init__(__self__, *,
                 disabled_tls_versions: Sequence[str],
                 minimum_key_size_settings: Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingResult'],
                 should_replace_certificates_operating_system: bool):
        """
        :param Sequence[str] disabled_tls_versions: The following post JRE installation actions are supported by the field:
               * Disable TLS 1.0 , TLS 1.1
        :param Sequence['GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingArgs'] minimum_key_size_settings: test
        :param bool should_replace_certificates_operating_system: Restores JDK root certificates with the certificates that are available in the operating system. The following action is supported by the field:
               * Replace JDK root certificates with a list provided by the operating system
        """
        pulumi.set(__self__, "disabled_tls_versions", disabled_tls_versions)
        pulumi.set(__self__, "minimum_key_size_settings", minimum_key_size_settings)
        pulumi.set(__self__, "should_replace_certificates_operating_system", should_replace_certificates_operating_system)

    @property
    @pulumi.getter(name="disabledTlsVersions")
    def disabled_tls_versions(self) -> Sequence[str]:
        """
        The following post JRE installation actions are supported by the field:
        * Disable TLS 1.0 , TLS 1.1
        """
        return pulumi.get(self, "disabled_tls_versions")

    @property
    @pulumi.getter(name="minimumKeySizeSettings")
    def minimum_key_size_settings(self) -> Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingResult']:
        """
        test
        """
        return pulumi.get(self, "minimum_key_size_settings")

    @property
    @pulumi.getter(name="shouldReplaceCertificatesOperatingSystem")
    def should_replace_certificates_operating_system(self) -> bool:
        """
        Restores JDK root certificates with the certificates that are available in the operating system. The following action is supported by the field:
        * Replace JDK root certificates with a list provided by the operating system
        """
        return pulumi.get(self, "should_replace_certificates_operating_system")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingResult(dict):
    def __init__(__self__, *,
                 certpaths: Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingCertpathResult'],
                 jars: Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingJarResult'],
                 tls: Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingTlResult']):
        """
        :param Sequence['GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingCertpathArgs'] certpaths: Updates the minimum key size for the specified encryption algorithm. The JDK property jdk.certpath.disabledAlgorithms will be updated with the following supported actions:
               * Changing minimum key length for RSA signed jars
               * Changing minimum key length for EC
               * Changing minimum key length for DSA
        :param Sequence['GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingJarArgs'] jars: Updates the minimum key size for the specified encryption algorithm. The JDK property jdk.jar.disabledAlgorithms will be updated with the following supported actions:
               * Changing minimum key length for RSA signed jars
               * Changing minimum key length for EC
               * Changing minimum key length for DSA
        :param Sequence['GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingTlArgs'] tls: Updates the minimum key size for the specified encryption algorithm. The JDK property jdk.tls.disabledAlgorithms will be updated with the following supported actions:
               * Changing minimum key length for Diffie-Hellman
        """
        pulumi.set(__self__, "certpaths", certpaths)
        pulumi.set(__self__, "jars", jars)
        pulumi.set(__self__, "tls", tls)

    @property
    @pulumi.getter
    def certpaths(self) -> Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingCertpathResult']:
        """
        Updates the minimum key size for the specified encryption algorithm. The JDK property jdk.certpath.disabledAlgorithms will be updated with the following supported actions:
        * Changing minimum key length for RSA signed jars
        * Changing minimum key length for EC
        * Changing minimum key length for DSA
        """
        return pulumi.get(self, "certpaths")

    @property
    @pulumi.getter
    def jars(self) -> Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingJarResult']:
        """
        Updates the minimum key size for the specified encryption algorithm. The JDK property jdk.jar.disabledAlgorithms will be updated with the following supported actions:
        * Changing minimum key length for RSA signed jars
        * Changing minimum key length for EC
        * Changing minimum key length for DSA
        """
        return pulumi.get(self, "jars")

    @property
    @pulumi.getter
    def tls(self) -> Sequence['outputs.GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingTlResult']:
        """
        Updates the minimum key size for the specified encryption algorithm. The JDK property jdk.tls.disabledAlgorithms will be updated with the following supported actions:
        * Changing minimum key length for Diffie-Hellman
        """
        return pulumi.get(self, "tls")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingCertpathResult(dict):
    def __init__(__self__, *,
                 key_size: int,
                 name: str):
        """
        :param int key_size: Key size for the encryption algorithm. Allowed values: 256 for EC, 2048 for DH/DSA/RSA
        :param str name: The algorithm name.
        """
        pulumi.set(__self__, "key_size", key_size)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="keySize")
    def key_size(self) -> int:
        """
        Key size for the encryption algorithm. Allowed values: 256 for EC, 2048 for DH/DSA/RSA
        """
        return pulumi.get(self, "key_size")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The algorithm name.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingJarResult(dict):
    def __init__(__self__, *,
                 key_size: int,
                 name: str):
        """
        :param int key_size: Key size for the encryption algorithm. Allowed values: 256 for EC, 2048 for DH/DSA/RSA
        :param str name: The algorithm name.
        """
        pulumi.set(__self__, "key_size", key_size)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="keySize")
    def key_size(self) -> int:
        """
        Key size for the encryption algorithm. Allowed values: 256 for EC, 2048 for DH/DSA/RSA
        """
        return pulumi.get(self, "key_size")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The algorithm name.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetFleetAdvancedFeatureConfigurationLcmPostInstallationActionMinimumKeySizeSettingTlResult(dict):
    def __init__(__self__, *,
                 key_size: int,
                 name: str):
        """
        :param int key_size: Key size for the encryption algorithm. Allowed values: 256 for EC, 2048 for DH/DSA/RSA
        :param str name: The algorithm name.
        """
        pulumi.set(__self__, "key_size", key_size)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="keySize")
    def key_size(self) -> int:
        """
        Key size for the encryption algorithm. Allowed values: 256 for EC, 2048 for DH/DSA/RSA
        """
        return pulumi.get(self, "key_size")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The algorithm name.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetFleetBlocklistsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetFleetBlocklistsItemResult(dict):
    def __init__(__self__, *,
                 key: str,
                 operation: str,
                 reason: str,
                 targets: Sequence['outputs.GetFleetBlocklistsItemTargetResult']):
        """
        :param str key: The unique identifier of this blocklist record.
        :param str operation: The operation type.
        :param str reason: The reason for why the operation is blocklisted
        :param Sequence['GetFleetBlocklistsItemTargetArgs'] targets: A resource to blocklist for certain operation.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "operation", operation)
        pulumi.set(__self__, "reason", reason)
        pulumi.set(__self__, "targets", targets)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The unique identifier of this blocklist record.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def operation(self) -> str:
        """
        The operation type.
        """
        return pulumi.get(self, "operation")

    @property
    @pulumi.getter
    def reason(self) -> str:
        """
        The reason for why the operation is blocklisted
        """
        return pulumi.get(self, "reason")

    @property
    @pulumi.getter
    def targets(self) -> Sequence['outputs.GetFleetBlocklistsItemTargetResult']:
        """
        A resource to blocklist for certain operation.
        """
        return pulumi.get(self, "targets")


@pulumi.output_type
class GetFleetBlocklistsItemTargetResult(dict):
    def __init__(__self__, *,
                 fleet_id: str,
                 installation_key: str,
                 managed_instance_id: str):
        """
        :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
        :param str installation_key: The unique identifier for the installation of Java Runtime at a specific path on a specific operating system.
        :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
        """
        pulumi.set(__self__, "fleet_id", fleet_id)
        pulumi.set(__self__, "installation_key", installation_key)
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)

    @property
    @pulumi.getter(name="fleetId")
    def fleet_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
        """
        return pulumi.get(self, "fleet_id")

    @property
    @pulumi.getter(name="installationKey")
    def installation_key(self) -> str:
        """
        The unique identifier for the installation of Java Runtime at a specific path on a specific operating system.
        """
        return pulumi.get(self, "installation_key")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> str:
        """
        The Fleet-unique identifier of the related managed instance.
        """
        return pulumi.get(self, "managed_instance_id")


@pulumi.output_type
class GetFleetCryptoAnalysisResultsCryptoAnalysisResultCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetFleetCryptoAnalysisResultsCryptoAnalysisResultCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetFleetCryptoAnalysisResultsCryptoAnalysisResultCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetFleetCryptoAnalysisResultsCryptoAnalysisResultCollectionItemResult(dict):
    def __init__(__self__, *,
                 aggregation_mode: str,
                 bucket: str,
                 crypto_roadmap_version: str,
                 finding_count: int,
                 fleet_id: str,
                 host_name: str,
                 id: str,
                 managed_instance_id: str,
                 namespace: str,
                 non_compliant_finding_count: int,
                 object: str,
                 summarized_event_count: int,
                 time_created: str,
                 time_first_event: str,
                 time_last_event: str,
                 total_event_count: int,
                 work_request_id: str):
        """
        :param str aggregation_mode: The aggregation mode of the crypto event analysis result.
        :param str bucket: The Object Storage bucket name of this analysis result.
        :param str crypto_roadmap_version: The Crypto Roadmap version used to perform the analysis.
        :param int finding_count: Total number of findings with the analysis.
        :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
        :param str host_name: The hostname of the managed instance.
        :param str id: The OCID to identify this analysis results.
        :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
        :param str namespace: The Object Storage namespace of this analysis result.
        :param int non_compliant_finding_count: Total number of non-compliant findings with the analysis. A non-compliant finding means the application won't work properly with the changes introduced by the crypto roadmap version used the the analysis.
        :param str object: The Object Storage object name of this analysis result.
        :param int summarized_event_count: Total number of summarized events. Summarized events are deduplicated events of interest.
        :param str time_created: The time the result is compiled.
        :param str time_first_event: Time of the first event in the analysis.
        :param str time_last_event: Time of the last event in the analysis.
        :param int total_event_count: Total number of events in the analysis.
        :param str work_request_id: The OCID of the work request to start the analysis.
        """
        pulumi.set(__self__, "aggregation_mode", aggregation_mode)
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "crypto_roadmap_version", crypto_roadmap_version)
        pulumi.set(__self__, "finding_count", finding_count)
        pulumi.set(__self__, "fleet_id", fleet_id)
        pulumi.set(__self__, "host_name", host_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "non_compliant_finding_count", non_compliant_finding_count)
        pulumi.set(__self__, "object", object)
        pulumi.set(__self__, "summarized_event_count", summarized_event_count)
        pulumi.set(__self__, "time_created", time_created)
        pulumi.set(__self__, "time_first_event", time_first_event)
        pulumi.set(__self__, "time_last_event", time_last_event)
        pulumi.set(__self__, "total_event_count", total_event_count)
        pulumi.set(__self__, "work_request_id", work_request_id)

    @property
    @pulumi.getter(name="aggregationMode")
    def aggregation_mode(self) -> str:
        """
        The aggregation mode of the crypto event analysis result.
        """
        return pulumi.get(self, "aggregation_mode")

    @property
    @pulumi.getter
    def bucket(self) -> str:
        """
        The Object Storage bucket name of this analysis result.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter(name="cryptoRoadmapVersion")
    def crypto_roadmap_version(self) -> str:
        """
        The Crypto Roadmap version used to perform the analysis.
        """
        return pulumi.get(self, "crypto_roadmap_version")

    @property
    @pulumi.getter(name="findingCount")
    def finding_count(self) -> int:
        """
        Total number of findings with the analysis.
        """
        return pulumi.get(self, "finding_count")

    @property
    @pulumi.getter(name="fleetId")
    def fleet_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
        """
        return pulumi.get(self, "fleet_id")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> str:
        """
        The hostname of the managed instance.
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID to identify this analysis results.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> str:
        """
        The Fleet-unique identifier of the related managed instance.
        """
        return pulumi.get(self, "managed_instance_id")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        The Object Storage namespace of this analysis result.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="nonCompliantFindingCount")
    def non_compliant_finding_count(self) -> int:
        """
        Total number of non-compliant findings with the analysis. A non-compliant finding means the application won't work properly with the changes introduced by the crypto roadmap version used the the analysis.
        """
        return pulumi.get(self, "non_compliant_finding_count")

    @property
    @pulumi.getter
    def object(self) -> str:
        """
        The Object Storage object name of this analysis result.
        """
        return pulumi.get(self, "object")

    @property
    @pulumi.getter(name="summarizedEventCount")
    def summarized_event_count(self) -> int:
        """
        Total number of summarized events. Summarized events are deduplicated events of interest.
        """
        return pulumi.get(self, "summarized_event_count")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the result is compiled.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeFirstEvent")
    def time_first_event(self) -> str:
        """
        Time of the first event in the analysis.
        """
        return pulumi.get(self, "time_first_event")

    @property
    @pulumi.getter(name="timeLastEvent")
    def time_last_event(self) -> str:
        """
        Time of the last event in the analysis.
        """
        return pulumi.get(self, "time_last_event")

    @property
    @pulumi.getter(name="totalEventCount")
    def total_event_count(self) -> int:
        """
        Total number of events in the analysis.
        """
        return pulumi.get(self, "total_event_count")

    @property
    @pulumi.getter(name="workRequestId")
    def work_request_id(self) -> str:
        """
        The OCID of the work request to start the analysis.
        """
        return pulumi.get(self, "work_request_id")


@pulumi.output_type
class GetFleetCryptoAnalysisResultsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetFleetInventoryLogResult(dict):
    def __init__(__self__, *,
                 log_group_id: str,
                 log_id: str):
        """
        :param str log_group_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        :param str log_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        pulumi.set(__self__, "log_group_id", log_group_id)
        pulumi.set(__self__, "log_id", log_id)

    @property
    @pulumi.getter(name="logGroupId")
    def log_group_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        """
        return pulumi.get(self, "log_group_id")

    @property
    @pulumi.getter(name="logId")
    def log_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        return pulumi.get(self, "log_id")


@pulumi.output_type
class GetFleetOperationLogResult(dict):
    def __init__(__self__, *,
                 log_group_id: str,
                 log_id: str):
        """
        :param str log_group_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        :param str log_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        pulumi.set(__self__, "log_group_id", log_group_id)
        pulumi.set(__self__, "log_id", log_id)

    @property
    @pulumi.getter(name="logGroupId")
    def log_group_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        """
        return pulumi.get(self, "log_group_id")

    @property
    @pulumi.getter(name="logId")
    def log_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        return pulumi.get(self, "log_id")


@pulumi.output_type
class GetFleetsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetFleetsFleetCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetFleetsFleetCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetFleetsFleetCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetFleetsFleetCollectionItemResult(dict):
    def __init__(__self__, *,
                 approximate_application_count: int,
                 approximate_installation_count: int,
                 approximate_java_server_count: int,
                 approximate_jre_count: int,
                 approximate_managed_instance_count: int,
                 compartment_id: str,
                 defined_tags: Mapping[str, Any],
                 description: str,
                 display_name: str,
                 freeform_tags: Mapping[str, Any],
                 id: str,
                 inventory_logs: Sequence['outputs.GetFleetsFleetCollectionItemInventoryLogResult'],
                 is_advanced_features_enabled: bool,
                 operation_logs: Sequence['outputs.GetFleetsFleetCollectionItemOperationLogResult'],
                 state: str,
                 system_tags: Mapping[str, Any],
                 time_created: str):
        """
        :param int approximate_application_count: The approximate count of all unique applications in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        :param int approximate_installation_count: The approximate count of all unique Java installations in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        :param int approximate_java_server_count: The approximate count of all unique Java servers in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        :param int approximate_jre_count: The approximate count of all unique Java Runtimes in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        :param int approximate_managed_instance_count: The approximate count of all unique managed instances in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which to list resources.
        :param Mapping[str, Any] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`. (See [Understanding Free-form Tags](https://docs.cloud.oracle.com/iaas/Content/Tagging/Tasks/managingtagsandtagnamespaces.htm)).
        :param str description: The Fleet's description.
        :param str display_name: The display name.
        :param Mapping[str, Any] freeform_tags: Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`. (See [Managing Tags and Tag Namespaces](https://docs.cloud.oracle.com/iaas/Content/Tagging/Concepts/understandingfreeformtags.htm).)
        :param str id: The ID of the Fleet.
        :param Sequence['GetFleetsFleetCollectionItemInventoryLogArgs'] inventory_logs: Custom Log for inventory or operation log.
        :param bool is_advanced_features_enabled: Whether or not advanced features are enabled in this fleet. Deprecated, use `/fleets/{fleetId}/advanceFeatureConfiguration` api instead.
        :param Sequence['GetFleetsFleetCollectionItemOperationLogArgs'] operation_logs: Custom Log for inventory or operation log.
        :param str state: The state of the lifecycle.
        :param Mapping[str, Any] system_tags: System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.  Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param str time_created: The creation date and time of the Fleet (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        pulumi.set(__self__, "approximate_application_count", approximate_application_count)
        pulumi.set(__self__, "approximate_installation_count", approximate_installation_count)
        pulumi.set(__self__, "approximate_java_server_count", approximate_java_server_count)
        pulumi.set(__self__, "approximate_jre_count", approximate_jre_count)
        pulumi.set(__self__, "approximate_managed_instance_count", approximate_managed_instance_count)
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "defined_tags", defined_tags)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "inventory_logs", inventory_logs)
        pulumi.set(__self__, "is_advanced_features_enabled", is_advanced_features_enabled)
        pulumi.set(__self__, "operation_logs", operation_logs)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "system_tags", system_tags)
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="approximateApplicationCount")
    def approximate_application_count(self) -> int:
        """
        The approximate count of all unique applications in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        """
        return pulumi.get(self, "approximate_application_count")

    @property
    @pulumi.getter(name="approximateInstallationCount")
    def approximate_installation_count(self) -> int:
        """
        The approximate count of all unique Java installations in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        """
        return pulumi.get(self, "approximate_installation_count")

    @property
    @pulumi.getter(name="approximateJavaServerCount")
    def approximate_java_server_count(self) -> int:
        """
        The approximate count of all unique Java servers in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        """
        return pulumi.get(self, "approximate_java_server_count")

    @property
    @pulumi.getter(name="approximateJreCount")
    def approximate_jre_count(self) -> int:
        """
        The approximate count of all unique Java Runtimes in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        """
        return pulumi.get(self, "approximate_jre_count")

    @property
    @pulumi.getter(name="approximateManagedInstanceCount")
    def approximate_managed_instance_count(self) -> int:
        """
        The approximate count of all unique managed instances in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
        """
        return pulumi.get(self, "approximate_managed_instance_count")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which to list resources.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`. (See [Understanding Free-form Tags](https://docs.cloud.oracle.com/iaas/Content/Tagging/Tasks/managingtagsandtagnamespaces.htm)).
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The Fleet's description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The display name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`. (See [Managing Tags and Tag Namespaces](https://docs.cloud.oracle.com/iaas/Content/Tagging/Concepts/understandingfreeformtags.htm).)
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Fleet.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inventoryLogs")
    def inventory_logs(self) -> Sequence['outputs.GetFleetsFleetCollectionItemInventoryLogResult']:
        """
        Custom Log for inventory or operation log.
        """
        return pulumi.get(self, "inventory_logs")

    @property
    @pulumi.getter(name="isAdvancedFeaturesEnabled")
    def is_advanced_features_enabled(self) -> bool:
        """
        Whether or not advanced features are enabled in this fleet. Deprecated, use `/fleets/{fleetId}/advanceFeatureConfiguration` api instead.
        """
        return pulumi.get(self, "is_advanced_features_enabled")

    @property
    @pulumi.getter(name="operationLogs")
    def operation_logs(self) -> Sequence['outputs.GetFleetsFleetCollectionItemOperationLogResult']:
        """
        Custom Log for inventory or operation log.
        """
        return pulumi.get(self, "operation_logs")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The state of the lifecycle.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.  Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The creation date and time of the Fleet (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "time_created")


@pulumi.output_type
class GetFleetsFleetCollectionItemInventoryLogResult(dict):
    def __init__(__self__, *,
                 log_group_id: str,
                 log_id: str):
        """
        :param str log_group_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        :param str log_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        pulumi.set(__self__, "log_group_id", log_group_id)
        pulumi.set(__self__, "log_id", log_id)

    @property
    @pulumi.getter(name="logGroupId")
    def log_group_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        """
        return pulumi.get(self, "log_group_id")

    @property
    @pulumi.getter(name="logId")
    def log_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        return pulumi.get(self, "log_id")


@pulumi.output_type
class GetFleetsFleetCollectionItemOperationLogResult(dict):
    def __init__(__self__, *,
                 log_group_id: str,
                 log_id: str):
        """
        :param str log_group_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        :param str log_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        pulumi.set(__self__, "log_group_id", log_group_id)
        pulumi.set(__self__, "log_id", log_id)

    @property
    @pulumi.getter(name="logGroupId")
    def log_group_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log group.
        """
        return pulumi.get(self, "log_group_id")

    @property
    @pulumi.getter(name="logId")
    def log_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the log.
        """
        return pulumi.get(self, "log_id")


@pulumi.output_type
class GetInstallationSiteItemResult(dict):
    def __init__(__self__, *,
                 approximate_application_count: int,
                 blocklists: Sequence['outputs.GetInstallationSiteItemBlocklistResult'],
                 installation_key: str,
                 jres: Sequence['outputs.GetInstallationSiteItemJreResult'],
                 managed_instance_id: str,
                 operating_systems: Sequence['outputs.GetInstallationSiteItemOperatingSystemResult'],
                 path: str,
                 security_status: str,
                 state: str,
                 time_last_seen: str):
        """
        :param int approximate_application_count: The approximate count of applications running on this installation
        :param Sequence['GetInstallationSiteItemBlocklistArgs'] blocklists: The list of operations that are blocklisted.
        :param str installation_key: The unique identifier for the installation of Java Runtime at a specific path on a specific operating system.
        :param Sequence['GetInstallationSiteItemJreArgs'] jres: The essential properties to identify a Java Runtime.
        :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
        :param Sequence['GetInstallationSiteItemOperatingSystemArgs'] operating_systems: Operating System of the platform on which the Java Runtime was reported.
        :param str path: The file system path of the installation.
        :param str security_status: The security status of the Java Runtime.
        :param str state: The lifecycle state of the installation site.
        :param str time_last_seen: The date and time the resource was _last_ reported to JMS. This is potentially _after_ the specified time period provided by the filters. For example, a resource can be last reported to JMS before the start of a specified time period, if it is also reported during the time period.
        """
        pulumi.set(__self__, "approximate_application_count", approximate_application_count)
        pulumi.set(__self__, "blocklists", blocklists)
        pulumi.set(__self__, "installation_key", installation_key)
        pulumi.set(__self__, "jres", jres)
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)
        pulumi.set(__self__, "operating_systems", operating_systems)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "security_status", security_status)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "time_last_seen", time_last_seen)

    @property
    @pulumi.getter(name="approximateApplicationCount")
    def approximate_application_count(self) -> int:
        """
        The approximate count of applications running on this installation
        """
        return pulumi.get(self, "approximate_application_count")

    @property
    @pulumi.getter
    def blocklists(self) -> Sequence['outputs.GetInstallationSiteItemBlocklistResult']:
        """
        The list of operations that are blocklisted.
        """
        return pulumi.get(self, "blocklists")

    @property
    @pulumi.getter(name="installationKey")
    def installation_key(self) -> str:
        """
        The unique identifier for the installation of Java Runtime at a specific path on a specific operating system.
        """
        return pulumi.get(self, "installation_key")

    @property
    @pulumi.getter
    def jres(self) -> Sequence['outputs.GetInstallationSiteItemJreResult']:
        """
        The essential properties to identify a Java Runtime.
        """
        return pulumi.get(self, "jres")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> str:
        """
        The Fleet-unique identifier of the related managed instance.
        """
        return pulumi.get(self, "managed_instance_id")

    @property
    @pulumi.getter(name="operatingSystems")
    def operating_systems(self) -> Sequence['outputs.GetInstallationSiteItemOperatingSystemResult']:
        """
        Operating System of the platform on which the Java Runtime was reported.
        """
        return pulumi.get(self, "operating_systems")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        The file system path of the installation.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="securityStatus")
    def security_status(self) -> str:
        """
        The security status of the Java Runtime.
        """
        return pulumi.get(self, "security_status")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The lifecycle state of the installation site.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeLastSeen")
    def time_last_seen(self) -> str:
        """
        The date and time the resource was _last_ reported to JMS. This is potentially _after_ the specified time period provided by the filters. For example, a resource can be last reported to JMS before the start of a specified time period, if it is also reported during the time period.
        """
        return pulumi.get(self, "time_last_seen")


@pulumi.output_type
class GetInstallationSiteItemBlocklistResult(dict):
    def __init__(__self__, *,
                 operation: str,
                 reason: str):
        """
        :param str operation: The operation type.
        :param str reason: The reason why the operation is blocklisted.
        """
        pulumi.set(__self__, "operation", operation)
        pulumi.set(__self__, "reason", reason)

    @property
    @pulumi.getter
    def operation(self) -> str:
        """
        The operation type.
        """
        return pulumi.get(self, "operation")

    @property
    @pulumi.getter
    def reason(self) -> str:
        """
        The reason why the operation is blocklisted.
        """
        return pulumi.get(self, "reason")


@pulumi.output_type
class GetInstallationSiteItemJreResult(dict):
    def __init__(__self__, *,
                 distribution: str,
                 jre_key: str,
                 vendor: str,
                 version: str):
        """
        :param str distribution: The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.
        :param str jre_key: The unique identifier for a Java Runtime.
        :param str vendor: The vendor of the Java Runtime.
        :param str version: The version of the operating system as provided by the Java system property os.version.
        """
        pulumi.set(__self__, "distribution", distribution)
        pulumi.set(__self__, "jre_key", jre_key)
        pulumi.set(__self__, "vendor", vendor)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def distribution(self) -> str:
        """
        The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.
        """
        return pulumi.get(self, "distribution")

    @property
    @pulumi.getter(name="jreKey")
    def jre_key(self) -> str:
        """
        The unique identifier for a Java Runtime.
        """
        return pulumi.get(self, "jre_key")

    @property
    @pulumi.getter
    def vendor(self) -> str:
        """
        The vendor of the Java Runtime.
        """
        return pulumi.get(self, "vendor")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The version of the operating system as provided by the Java system property os.version.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetInstallationSiteItemOperatingSystemResult(dict):
    def __init__(__self__, *,
                 architecture: str,
                 family: str,
                 managed_instance_count: int,
                 name: str,
                 version: str):
        """
        :param str architecture: The architecture of the operating system as provided by the Java system property os.arch.
        :param str family: The operating system type, such as Windows or Linux
        :param int managed_instance_count: Number of instances running the operating system
        :param str name: The name of the operating system as provided by the Java system property os.name.
        :param str version: The version of the operating system as provided by the Java system property os.version.
        """
        pulumi.set(__self__, "architecture", architecture)
        pulumi.set(__self__, "family", family)
        pulumi.set(__self__, "managed_instance_count", managed_instance_count)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def architecture(self) -> str:
        """
        The architecture of the operating system as provided by the Java system property os.arch.
        """
        return pulumi.get(self, "architecture")

    @property
    @pulumi.getter
    def family(self) -> str:
        """
        The operating system type, such as Windows or Linux
        """
        return pulumi.get(self, "family")

    @property
    @pulumi.getter(name="managedInstanceCount")
    def managed_instance_count(self) -> int:
        """
        Number of instances running the operating system
        """
        return pulumi.get(self, "managed_instance_count")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the operating system as provided by the Java system property os.name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The version of the operating system as provided by the Java system property os.version.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetInstallationSitesFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: The name of the operating system as provided by the Java system property os.name.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the operating system as provided by the Java system property os.name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetInstallationSitesInstallationSiteCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemResult']):
        """
        :param Sequence['GetInstallationSitesInstallationSiteCollectionItemArgs'] items: A list of Java installation sites.
        """
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemResult']:
        """
        A list of Java installation sites.
        """
        return pulumi.get(self, "items")


@pulumi.output_type
class GetInstallationSitesInstallationSiteCollectionItemResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemItemResult']):
        """
        :param Sequence['GetInstallationSitesInstallationSiteCollectionItemItemArgs'] items: A list of Java installation sites.
        """
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemItemResult']:
        """
        A list of Java installation sites.
        """
        return pulumi.get(self, "items")


@pulumi.output_type
class GetInstallationSitesInstallationSiteCollectionItemItemResult(dict):
    def __init__(__self__, *,
                 approximate_application_count: int,
                 blocklists: Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemItemBlocklistResult'],
                 installation_key: str,
                 jres: Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemItemJreResult'],
                 managed_instance_id: str,
                 operating_systems: Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemItemOperatingSystemResult'],
                 path: str,
                 security_status: str,
                 state: str,
                 time_last_seen: str):
        """
        :param int approximate_application_count: The approximate count of applications running on this installation
        :param Sequence['GetInstallationSitesInstallationSiteCollectionItemItemBlocklistArgs'] blocklists: The list of operations that are blocklisted.
        :param str installation_key: The unique identifier for the installation of Java Runtime at a specific path on a specific operating system.
        :param Sequence['GetInstallationSitesInstallationSiteCollectionItemItemJreArgs'] jres: The essential properties to identify a Java Runtime.
        :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
        :param Sequence['GetInstallationSitesInstallationSiteCollectionItemItemOperatingSystemArgs'] operating_systems: Operating System of the platform on which the Java Runtime was reported.
        :param str path: The file system path of the installation.
        :param str security_status: The security status of the Java Runtime.
        :param str state: The lifecycle state of the installation site.
        :param str time_last_seen: The date and time the resource was _last_ reported to JMS. This is potentially _after_ the specified time period provided by the filters. For example, a resource can be last reported to JMS before the start of a specified time period, if it is also reported during the time period.
        """
        pulumi.set(__self__, "approximate_application_count", approximate_application_count)
        pulumi.set(__self__, "blocklists", blocklists)
        pulumi.set(__self__, "installation_key", installation_key)
        pulumi.set(__self__, "jres", jres)
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)
        pulumi.set(__self__, "operating_systems", operating_systems)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "security_status", security_status)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "time_last_seen", time_last_seen)

    @property
    @pulumi.getter(name="approximateApplicationCount")
    def approximate_application_count(self) -> int:
        """
        The approximate count of applications running on this installation
        """
        return pulumi.get(self, "approximate_application_count")

    @property
    @pulumi.getter
    def blocklists(self) -> Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemItemBlocklistResult']:
        """
        The list of operations that are blocklisted.
        """
        return pulumi.get(self, "blocklists")

    @property
    @pulumi.getter(name="installationKey")
    def installation_key(self) -> str:
        """
        The unique identifier for the installation of Java Runtime at a specific path on a specific operating system.
        """
        return pulumi.get(self, "installation_key")

    @property
    @pulumi.getter
    def jres(self) -> Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemItemJreResult']:
        """
        The essential properties to identify a Java Runtime.
        """
        return pulumi.get(self, "jres")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> str:
        """
        The Fleet-unique identifier of the related managed instance.
        """
        return pulumi.get(self, "managed_instance_id")

    @property
    @pulumi.getter(name="operatingSystems")
    def operating_systems(self) -> Sequence['outputs.GetInstallationSitesInstallationSiteCollectionItemItemOperatingSystemResult']:
        """
        Operating System of the platform on which the Java Runtime was reported.
        """
        return pulumi.get(self, "operating_systems")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        The file system path of the installation.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="securityStatus")
    def security_status(self) -> str:
        """
        The security status of the Java Runtime.
        """
        return pulumi.get(self, "security_status")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The lifecycle state of the installation site.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeLastSeen")
    def time_last_seen(self) -> str:
        """
        The date and time the resource was _last_ reported to JMS. This is potentially _after_ the specified time period provided by the filters. For example, a resource can be last reported to JMS before the start of a specified time period, if it is also reported during the time period.
        """
        return pulumi.get(self, "time_last_seen")


@pulumi.output_type
class GetInstallationSitesInstallationSiteCollectionItemItemBlocklistResult(dict):
    def __init__(__self__, *,
                 operation: str,
                 reason: str):
        """
        :param str operation: The operation type.
        :param str reason: The reason why the operation is blocklisted.
        """
        pulumi.set(__self__, "operation", operation)
        pulumi.set(__self__, "reason", reason)

    @property
    @pulumi.getter
    def operation(self) -> str:
        """
        The operation type.
        """
        return pulumi.get(self, "operation")

    @property
    @pulumi.getter
    def reason(self) -> str:
        """
        The reason why the operation is blocklisted.
        """
        return pulumi.get(self, "reason")


@pulumi.output_type
class GetInstallationSitesInstallationSiteCollectionItemItemJreResult(dict):
    def __init__(__self__, *,
                 distribution: str,
                 jre_key: str,
                 vendor: str,
                 version: str):
        """
        :param str distribution: The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.
        :param str jre_key: The unique identifier for a Java Runtime.
        :param str vendor: The vendor of the Java Runtime.
        :param str version: The version of the operating system as provided by the Java system property os.version.
        """
        pulumi.set(__self__, "distribution", distribution)
        pulumi.set(__self__, "jre_key", jre_key)
        pulumi.set(__self__, "vendor", vendor)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def distribution(self) -> str:
        """
        The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.
        """
        return pulumi.get(self, "distribution")

    @property
    @pulumi.getter(name="jreKey")
    def jre_key(self) -> str:
        """
        The unique identifier for a Java Runtime.
        """
        return pulumi.get(self, "jre_key")

    @property
    @pulumi.getter
    def vendor(self) -> str:
        """
        The vendor of the Java Runtime.
        """
        return pulumi.get(self, "vendor")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The version of the operating system as provided by the Java system property os.version.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetInstallationSitesInstallationSiteCollectionItemItemOperatingSystemResult(dict):
    def __init__(__self__, *,
                 architecture: str,
                 family: str,
                 managed_instance_count: int,
                 name: str,
                 version: str):
        """
        :param str architecture: The architecture of the operating system as provided by the Java system property os.arch.
        :param str family: The operating system type, such as Windows or Linux
        :param int managed_instance_count: Number of instances running the operating system
        :param str name: The name of the operating system as provided by the Java system property os.name.
        :param str version: The version of the operating system as provided by the Java system property os.version.
        """
        pulumi.set(__self__, "architecture", architecture)
        pulumi.set(__self__, "family", family)
        pulumi.set(__self__, "managed_instance_count", managed_instance_count)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def architecture(self) -> str:
        """
        The architecture of the operating system as provided by the Java system property os.arch.
        """
        return pulumi.get(self, "architecture")

    @property
    @pulumi.getter
    def family(self) -> str:
        """
        The operating system type, such as Windows or Linux
        """
        return pulumi.get(self, "family")

    @property
    @pulumi.getter(name="managedInstanceCount")
    def managed_instance_count(self) -> int:
        """
        Number of instances running the operating system
        """
        return pulumi.get(self, "managed_instance_count")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the operating system as provided by the Java system property os.name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The version of the operating system as provided by the Java system property os.version.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetJavaFamiliesFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetJavaFamiliesJavaFamilyCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetJavaFamiliesJavaFamilyCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetJavaFamiliesJavaFamilyCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetJavaFamiliesJavaFamilyCollectionItemResult(dict):
    def __init__(__self__, *,
                 display_name: str,
                 doc_url: str,
                 end_of_support_life_date: str,
                 family_version: str,
                 support_type: str):
        """
        :param str display_name: The display name for the Java family.
        :param str doc_url: Link to access the documentation for the release.
        :param str end_of_support_life_date: The End of Support Life (EOSL) date of the Java release family (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param str family_version: The version identifier for the Java family.
        :param str support_type: This indicates the support category for the Java release family.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "doc_url", doc_url)
        pulumi.set(__self__, "end_of_support_life_date", end_of_support_life_date)
        pulumi.set(__self__, "family_version", family_version)
        pulumi.set(__self__, "support_type", support_type)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The display name for the Java family.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="docUrl")
    def doc_url(self) -> str:
        """
        Link to access the documentation for the release.
        """
        return pulumi.get(self, "doc_url")

    @property
    @pulumi.getter(name="endOfSupportLifeDate")
    def end_of_support_life_date(self) -> str:
        """
        The End of Support Life (EOSL) date of the Java release family (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "end_of_support_life_date")

    @property
    @pulumi.getter(name="familyVersion")
    def family_version(self) -> str:
        """
        The version identifier for the Java family.
        """
        return pulumi.get(self, "family_version")

    @property
    @pulumi.getter(name="supportType")
    def support_type(self) -> str:
        """
        This indicates the support category for the Java release family.
        """
        return pulumi.get(self, "support_type")


@pulumi.output_type
class GetJavaReleaseArtifactResult(dict):
    def __init__(__self__, *,
                 approximate_file_size_in_bytes: str,
                 artifact_content_type: str,
                 artifact_description: str,
                 artifact_id: str,
                 sha256: str):
        """
        :param str approximate_file_size_in_bytes: Approximate compressed file size in bytes.
        :param str artifact_content_type: Product content type of this artifact.
        :param str artifact_description: Description of the binary artifact. Typically includes the OS, architecture, and installer type.
        :param str artifact_id: Unique identifier for the artifact.
        :param str sha256: SHA256 checksum of the artifact.
        """
        pulumi.set(__self__, "approximate_file_size_in_bytes", approximate_file_size_in_bytes)
        pulumi.set(__self__, "artifact_content_type", artifact_content_type)
        pulumi.set(__self__, "artifact_description", artifact_description)
        pulumi.set(__self__, "artifact_id", artifact_id)
        pulumi.set(__self__, "sha256", sha256)

    @property
    @pulumi.getter(name="approximateFileSizeInBytes")
    def approximate_file_size_in_bytes(self) -> str:
        """
        Approximate compressed file size in bytes.
        """
        return pulumi.get(self, "approximate_file_size_in_bytes")

    @property
    @pulumi.getter(name="artifactContentType")
    def artifact_content_type(self) -> str:
        """
        Product content type of this artifact.
        """
        return pulumi.get(self, "artifact_content_type")

    @property
    @pulumi.getter(name="artifactDescription")
    def artifact_description(self) -> str:
        """
        Description of the binary artifact. Typically includes the OS, architecture, and installer type.
        """
        return pulumi.get(self, "artifact_description")

    @property
    @pulumi.getter(name="artifactId")
    def artifact_id(self) -> str:
        """
        Unique identifier for the artifact.
        """
        return pulumi.get(self, "artifact_id")

    @property
    @pulumi.getter
    def sha256(self) -> str:
        """
        SHA256 checksum of the artifact.
        """
        return pulumi.get(self, "sha256")


@pulumi.output_type
class GetJavaReleaseFamilyDetailResult(dict):
    def __init__(__self__, *,
                 display_name: str,
                 doc_url: str,
                 end_of_support_life_date: str,
                 family_version: str,
                 support_type: str):
        """
        :param str display_name: Commonly used name for the license type.
        :param str doc_url: Link to access the documentation for the release.
        :param str end_of_support_life_date: The End of Support Life (EOSL) date of the Java release family (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param str family_version: Java release family identifier.
        :param str support_type: This indicates the support category for the Java release family.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "doc_url", doc_url)
        pulumi.set(__self__, "end_of_support_life_date", end_of_support_life_date)
        pulumi.set(__self__, "family_version", family_version)
        pulumi.set(__self__, "support_type", support_type)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Commonly used name for the license type.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="docUrl")
    def doc_url(self) -> str:
        """
        Link to access the documentation for the release.
        """
        return pulumi.get(self, "doc_url")

    @property
    @pulumi.getter(name="endOfSupportLifeDate")
    def end_of_support_life_date(self) -> str:
        """
        The End of Support Life (EOSL) date of the Java release family (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "end_of_support_life_date")

    @property
    @pulumi.getter(name="familyVersion")
    def family_version(self) -> str:
        """
        Java release family identifier.
        """
        return pulumi.get(self, "family_version")

    @property
    @pulumi.getter(name="supportType")
    def support_type(self) -> str:
        """
        This indicates the support category for the Java release family.
        """
        return pulumi.get(self, "support_type")


@pulumi.output_type
class GetJavaReleaseLicenseDetailResult(dict):
    def __init__(__self__, *,
                 display_name: str,
                 license_type: str,
                 license_url: str):
        """
        :param str display_name: Commonly used name for the license type.
        :param str license_type: License type for the Java version.
        :param str license_url: Publicly accessible license URL containing the detailed terms and conditions.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "license_type", license_type)
        pulumi.set(__self__, "license_url", license_url)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Commonly used name for the license type.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> str:
        """
        License type for the Java version.
        """
        return pulumi.get(self, "license_type")

    @property
    @pulumi.getter(name="licenseUrl")
    def license_url(self) -> str:
        """
        Publicly accessible license URL containing the detailed terms and conditions.
        """
        return pulumi.get(self, "license_url")


@pulumi.output_type
class GetJavaReleasesFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetJavaReleasesJavaReleaseCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetJavaReleasesJavaReleaseCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetJavaReleasesJavaReleaseCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetJavaReleasesJavaReleaseCollectionItemResult(dict):
    def __init__(__self__, *,
                 artifact_content_types: Sequence[str],
                 artifacts: Sequence['outputs.GetJavaReleasesJavaReleaseCollectionItemArtifactResult'],
                 family_details: Sequence['outputs.GetJavaReleasesJavaReleaseCollectionItemFamilyDetailResult'],
                 family_version: str,
                 license_details: Sequence['outputs.GetJavaReleasesJavaReleaseCollectionItemLicenseDetailResult'],
                 license_type: str,
                 parent_release_version: str,
                 release_date: str,
                 release_notes_url: str,
                 release_type: str,
                 release_version: str,
                 security_status: str):
        """
        :param Sequence[str] artifact_content_types: Artifact content types for the Java version.
        :param Sequence['GetJavaReleasesJavaReleaseCollectionItemArtifactArgs'] artifacts: List of Java artifacts.
        :param Sequence['GetJavaReleasesJavaReleaseCollectionItemFamilyDetailArgs'] family_details: Metadata associated with a specific Java release family. A Java release family is typically a major version in the Java version identifier.
        :param str family_version: The version identifier for the Java family.
        :param Sequence['GetJavaReleasesJavaReleaseCollectionItemLicenseDetailArgs'] license_details: Information about a license type for Java.
        :param str license_type: Java license type.
        :param str parent_release_version: Parent Java release version identifier. This is applicable for BPR releases.
        :param str release_date: The release date of the Java version (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param str release_notes_url: Release notes associated with the Java version.
        :param str release_type: Java release type.
        :param str release_version: Unique Java release version identifier
        :param str security_status: The security status of the Java version.
        """
        pulumi.set(__self__, "artifact_content_types", artifact_content_types)
        pulumi.set(__self__, "artifacts", artifacts)
        pulumi.set(__self__, "family_details", family_details)
        pulumi.set(__self__, "family_version", family_version)
        pulumi.set(__self__, "license_details", license_details)
        pulumi.set(__self__, "license_type", license_type)
        pulumi.set(__self__, "parent_release_version", parent_release_version)
        pulumi.set(__self__, "release_date", release_date)
        pulumi.set(__self__, "release_notes_url", release_notes_url)
        pulumi.set(__self__, "release_type", release_type)
        pulumi.set(__self__, "release_version", release_version)
        pulumi.set(__self__, "security_status", security_status)

    @property
    @pulumi.getter(name="artifactContentTypes")
    def artifact_content_types(self) -> Sequence[str]:
        """
        Artifact content types for the Java version.
        """
        return pulumi.get(self, "artifact_content_types")

    @property
    @pulumi.getter
    def artifacts(self) -> Sequence['outputs.GetJavaReleasesJavaReleaseCollectionItemArtifactResult']:
        """
        List of Java artifacts.
        """
        return pulumi.get(self, "artifacts")

    @property
    @pulumi.getter(name="familyDetails")
    def family_details(self) -> Sequence['outputs.GetJavaReleasesJavaReleaseCollectionItemFamilyDetailResult']:
        """
        Metadata associated with a specific Java release family. A Java release family is typically a major version in the Java version identifier.
        """
        return pulumi.get(self, "family_details")

    @property
    @pulumi.getter(name="familyVersion")
    def family_version(self) -> str:
        """
        The version identifier for the Java family.
        """
        return pulumi.get(self, "family_version")

    @property
    @pulumi.getter(name="licenseDetails")
    def license_details(self) -> Sequence['outputs.GetJavaReleasesJavaReleaseCollectionItemLicenseDetailResult']:
        """
        Information about a license type for Java.
        """
        return pulumi.get(self, "license_details")

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> str:
        """
        Java license type.
        """
        return pulumi.get(self, "license_type")

    @property
    @pulumi.getter(name="parentReleaseVersion")
    def parent_release_version(self) -> str:
        """
        Parent Java release version identifier. This is applicable for BPR releases.
        """
        return pulumi.get(self, "parent_release_version")

    @property
    @pulumi.getter(name="releaseDate")
    def release_date(self) -> str:
        """
        The release date of the Java version (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "release_date")

    @property
    @pulumi.getter(name="releaseNotesUrl")
    def release_notes_url(self) -> str:
        """
        Release notes associated with the Java version.
        """
        return pulumi.get(self, "release_notes_url")

    @property
    @pulumi.getter(name="releaseType")
    def release_type(self) -> str:
        """
        Java release type.
        """
        return pulumi.get(self, "release_type")

    @property
    @pulumi.getter(name="releaseVersion")
    def release_version(self) -> str:
        """
        Unique Java release version identifier
        """
        return pulumi.get(self, "release_version")

    @property
    @pulumi.getter(name="securityStatus")
    def security_status(self) -> str:
        """
        The security status of the Java version.
        """
        return pulumi.get(self, "security_status")


@pulumi.output_type
class GetJavaReleasesJavaReleaseCollectionItemArtifactResult(dict):
    def __init__(__self__, *,
                 approximate_file_size_in_bytes: str,
                 artifact_content_type: str,
                 artifact_description: str,
                 artifact_id: str,
                 sha256: str):
        """
        :param str approximate_file_size_in_bytes: Approximate compressed file size in bytes.
        :param str artifact_content_type: Product content type of this artifact.
        :param str artifact_description: Description of the binary artifact. Typically includes the OS, architecture, and installer type.
        :param str artifact_id: Unique identifier for the artifact.
        :param str sha256: SHA256 checksum of the artifact.
        """
        pulumi.set(__self__, "approximate_file_size_in_bytes", approximate_file_size_in_bytes)
        pulumi.set(__self__, "artifact_content_type", artifact_content_type)
        pulumi.set(__self__, "artifact_description", artifact_description)
        pulumi.set(__self__, "artifact_id", artifact_id)
        pulumi.set(__self__, "sha256", sha256)

    @property
    @pulumi.getter(name="approximateFileSizeInBytes")
    def approximate_file_size_in_bytes(self) -> str:
        """
        Approximate compressed file size in bytes.
        """
        return pulumi.get(self, "approximate_file_size_in_bytes")

    @property
    @pulumi.getter(name="artifactContentType")
    def artifact_content_type(self) -> str:
        """
        Product content type of this artifact.
        """
        return pulumi.get(self, "artifact_content_type")

    @property
    @pulumi.getter(name="artifactDescription")
    def artifact_description(self) -> str:
        """
        Description of the binary artifact. Typically includes the OS, architecture, and installer type.
        """
        return pulumi.get(self, "artifact_description")

    @property
    @pulumi.getter(name="artifactId")
    def artifact_id(self) -> str:
        """
        Unique identifier for the artifact.
        """
        return pulumi.get(self, "artifact_id")

    @property
    @pulumi.getter
    def sha256(self) -> str:
        """
        SHA256 checksum of the artifact.
        """
        return pulumi.get(self, "sha256")


@pulumi.output_type
class GetJavaReleasesJavaReleaseCollectionItemFamilyDetailResult(dict):
    def __init__(__self__, *,
                 display_name: str,
                 doc_url: str,
                 end_of_support_life_date: str,
                 family_version: str,
                 support_type: str):
        """
        :param str display_name: Commonly used name for the license type.
        :param str doc_url: Link to access the documentation for the release.
        :param str end_of_support_life_date: The End of Support Life (EOSL) date of the Java release family (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param str family_version: The version identifier for the Java family.
        :param str support_type: This indicates the support category for the Java release family.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "doc_url", doc_url)
        pulumi.set(__self__, "end_of_support_life_date", end_of_support_life_date)
        pulumi.set(__self__, "family_version", family_version)
        pulumi.set(__self__, "support_type", support_type)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Commonly used name for the license type.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="docUrl")
    def doc_url(self) -> str:
        """
        Link to access the documentation for the release.
        """
        return pulumi.get(self, "doc_url")

    @property
    @pulumi.getter(name="endOfSupportLifeDate")
    def end_of_support_life_date(self) -> str:
        """
        The End of Support Life (EOSL) date of the Java release family (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "end_of_support_life_date")

    @property
    @pulumi.getter(name="familyVersion")
    def family_version(self) -> str:
        """
        The version identifier for the Java family.
        """
        return pulumi.get(self, "family_version")

    @property
    @pulumi.getter(name="supportType")
    def support_type(self) -> str:
        """
        This indicates the support category for the Java release family.
        """
        return pulumi.get(self, "support_type")


@pulumi.output_type
class GetJavaReleasesJavaReleaseCollectionItemLicenseDetailResult(dict):
    def __init__(__self__, *,
                 display_name: str,
                 license_type: str,
                 license_url: str):
        """
        :param str display_name: Commonly used name for the license type.
        :param str license_type: Java license type.
        :param str license_url: Publicly accessible license URL containing the detailed terms and conditions.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "license_type", license_type)
        pulumi.set(__self__, "license_url", license_url)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Commonly used name for the license type.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> str:
        """
        Java license type.
        """
        return pulumi.get(self, "license_type")

    @property
    @pulumi.getter(name="licenseUrl")
    def license_url(self) -> str:
        """
        Publicly accessible license URL containing the detailed terms and conditions.
        """
        return pulumi.get(self, "license_url")


@pulumi.output_type
class GetListJreUsageItemResult(dict):
    def __init__(__self__, *,
                 approximate_application_count: int,
                 approximate_installation_count: int,
                 approximate_managed_instance_count: int,
                 approximate_pending_work_request_count: int,
                 days_under_security_baseline: int,
                 distribution: str,
                 end_of_support_life_date: str,
                 fleet_id: str,
                 id: str,
                 managed_instance_id: str,
                 operating_systems: Sequence['outputs.GetListJreUsageItemOperatingSystemResult'],
                 release_date: str,
                 security_status: str,
                 time_end: str,
                 time_first_seen: str,
                 time_last_seen: str,
                 time_start: str,
                 vendor: str,
                 version: str):
        """
        :param int approximate_application_count: The approximate count of the applications running on this Java Runtime.
        :param int approximate_installation_count: The approximate count of installations that are installations of this Java Runtime.
        :param int approximate_managed_instance_count: The approximate count of the managed instances that report this Java Runtime.
        :param int approximate_pending_work_request_count: The approximate count of work requests working on this Java Runtime.
        :param int days_under_security_baseline: The number of days since this release has been under the security baseline.
        :param str distribution: The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.
        :param str end_of_support_life_date: The End of Support Life (EOSL) date of the Java Runtime (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the related fleet.
        :param str id: The internal identifier of the Java Runtime.
        :param str managed_instance_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the related managed instance. This property value is present only for /listJreUsage.
        :param Sequence['GetListJreUsageItemOperatingSystemArgs'] operating_systems: The operating systems that have this Java Runtime installed.
        :param str release_date: The release date of the Java Runtime (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param str security_status: The security status of the Java Runtime.
        :param str time_end: The end of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param str time_first_seen: The date and time the resource was _first_ reported to JMS. This is potentially _before_ the specified time period provided by the filters. For example, a resource can be first reported to JMS before the start of a specified time period, if it is also reported during the time period.
        :param str time_last_seen: The date and time the resource was _last_ reported to JMS. This is potentially _after_ the specified time period provided by the filters. For example, a resource can be last reported to JMS before the start of a specified time period, if it is also reported during the time period.
        :param str time_start: The start of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param str vendor: The vendor of the Java Runtime.
        :param str version: The version of the Java Runtime.
        """
        pulumi.set(__self__, "approximate_application_count", approximate_application_count)
        pulumi.set(__self__, "approximate_installation_count", approximate_installation_count)
        pulumi.set(__self__, "approximate_managed_instance_count", approximate_managed_instance_count)
        pulumi.set(__self__, "approximate_pending_work_request_count", approximate_pending_work_request_count)
        pulumi.set(__self__, "days_under_security_baseline", days_under_security_baseline)
        pulumi.set(__self__, "distribution", distribution)
        pulumi.set(__self__, "end_of_support_life_date", end_of_support_life_date)
        pulumi.set(__self__, "fleet_id", fleet_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)
        pulumi.set(__self__, "operating_systems", operating_systems)
        pulumi.set(__self__, "release_date", release_date)
        pulumi.set(__self__, "security_status", security_status)
        pulumi.set(__self__, "time_end", time_end)
        pulumi.set(__self__, "time_first_seen", time_first_seen)
        pulumi.set(__self__, "time_last_seen", time_last_seen)
        pulumi.set(__self__, "time_start", time_start)
        pulumi.set(__self__, "vendor", vendor)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="approximateApplicationCount")
    def approximate_application_count(self) -> int:
        """
        The approximate count of the applications running on this Java Runtime.
        """
        return pulumi.get(self, "approximate_application_count")

    @property
    @pulumi.getter(name="approximateInstallationCount")
    def approximate_installation_count(self) -> int:
        """
        The approximate count of installations that are installations of this Java Runtime.
        """
        return pulumi.get(self, "approximate_installation_count")

    @property
    @pulumi.getter(name="approximateManagedInstanceCount")
    def approximate_managed_instance_count(self) -> int:
        """
        The approximate count of the managed instances that report this Java Runtime.
        """
        return pulumi.get(self, "approximate_managed_instance_count")

    @property
    @pulumi.getter(name="approximatePendingWorkRequestCount")
    def approximate_pending_work_request_count(self) -> int:
        """
        The approximate count of work requests working on this Java Runtime.
        """
        return pulumi.get(self, "approximate_pending_work_request_count")

    @property
    @pulumi.getter(name="daysUnderSecurityBaseline")
    def days_under_security_baseline(self) -> int:
        """
        The number of days since this release has been under the security baseline.
        """
        return pulumi.get(self, "days_under_security_baseline")

    @property
    @pulumi.getter
    def distribution(self) -> str:
        """
        The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.
        """
        return pulumi.get(self, "distribution")

    @property
    @pulumi.getter(name="endOfSupportLifeDate")
    def end_of_support_life_date(self) -> str:
        """
        The End of Support Life (EOSL) date of the Java Runtime (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "end_of_support_life_date")

    @property
    @pulumi.getter(name="fleetId")
    def fleet_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the related fleet.
        """
        return pulumi.get(self, "fleet_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The internal identifier of the Java Runtime.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the related managed instance. This property value is present only for /listJreUsage.
        """
        return pulumi.get(self, "managed_instance_id")

    @property
    @pulumi.getter(name="operatingSystems")
    def operating_systems(self) -> Sequence['outputs.GetListJreUsageItemOperatingSystemResult']:
        """
        The operating systems that have this Java Runtime installed.
        """
        return pulumi.get(self, "operating_systems")

    @property
    @pulumi.getter(name="releaseDate")
    def release_date(self) -> str:
        """
        The release date of the Java Runtime (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "release_date")

    @property
    @pulumi.getter(name="securityStatus")
    def security_status(self) -> str:
        """
        The security status of the Java Runtime.
        """
        return pulumi.get(self, "security_status")

    @property
    @pulumi.getter(name="timeEnd")
    def time_end(self) -> str:
        """
        The end of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "time_end")

    @property
    @pulumi.getter(name="timeFirstSeen")
    def time_first_seen(self) -> str:
        """
        The date and time the resource was _first_ reported to JMS. This is potentially _before_ the specified time period provided by the filters. For example, a resource can be first reported to JMS before the start of a specified time period, if it is also reported during the time period.
        """
        return pulumi.get(self, "time_first_seen")

    @property
    @pulumi.getter(name="timeLastSeen")
    def time_last_seen(self) -> str:
        """
        The date and time the resource was _last_ reported to JMS. This is potentially _after_ the specified time period provided by the filters. For example, a resource can be last reported to JMS before the start of a specified time period, if it is also reported during the time period.
        """
        return pulumi.get(self, "time_last_seen")

    @property
    @pulumi.getter(name="timeStart")
    def time_start(self) -> str:
        """
        The start of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "time_start")

    @property
    @pulumi.getter
    def vendor(self) -> str:
        """
        The vendor of the Java Runtime.
        """
        return pulumi.get(self, "vendor")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The version of the Java Runtime.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetListJreUsageItemOperatingSystemResult(dict):
    def __init__(__self__, *,
                 architecture: str,
                 family: str,
                 managed_instance_count: int,
                 name: str,
                 version: str):
        """
        :param str architecture: The architecture of the operating system as provided by the Java system property os.arch.
        :param str family: The operating system type, such as Windows or Linux
        :param int managed_instance_count: Number of instances running the operating system
        :param str name: The name of the operating system as provided by the Java system property os.name.
        :param str version: The version of the Java Runtime.
        """
        pulumi.set(__self__, "architecture", architecture)
        pulumi.set(__self__, "family", family)
        pulumi.set(__self__, "managed_instance_count", managed_instance_count)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def architecture(self) -> str:
        """
        The architecture of the operating system as provided by the Java system property os.arch.
        """
        return pulumi.get(self, "architecture")

    @property
    @pulumi.getter
    def family(self) -> str:
        """
        The operating system type, such as Windows or Linux
        """
        return pulumi.get(self, "family")

    @property
    @pulumi.getter(name="managedInstanceCount")
    def managed_instance_count(self) -> int:
        """
        Number of instances running the operating system
        """
        return pulumi.get(self, "managed_instance_count")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the operating system as provided by the Java system property os.name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The version of the Java Runtime.
        """
        return pulumi.get(self, "version")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetDataGuardAssociationResult',
    'AwaitableGetDataGuardAssociationResult',
    'get_data_guard_association',
    'get_data_guard_association_output',
]

@pulumi.output_type
class GetDataGuardAssociationResult:
    """
    A collection of values returned by getDataGuardAssociation.
    """
    def __init__(__self__, apply_lag=None, apply_rate=None, availability_domain=None, backup_network_nsg_ids=None, cpu_core_count=None, create_async=None, creation_type=None, data_collection_options=None, data_guard_association_id=None, database_admin_password=None, database_defined_tags=None, database_freeform_tags=None, database_id=None, database_software_image_id=None, db_system_defined_tags=None, db_system_freeform_tags=None, delete_standby_db_home_on_delete=None, display_name=None, fault_domains=None, hostname=None, id=None, is_active_data_guard_enabled=None, license_model=None, lifecycle_details=None, node_count=None, nsg_ids=None, peer_data_guard_association_id=None, peer_database_id=None, peer_db_home_id=None, peer_db_system_id=None, peer_db_unique_name=None, peer_role=None, peer_sid_prefix=None, peer_vm_cluster_id=None, private_ip=None, protection_mode=None, role=None, shape=None, state=None, storage_volume_performance_mode=None, subnet_id=None, time_created=None, time_zone=None, transport_type=None):
        if apply_lag and not isinstance(apply_lag, str):
            raise TypeError("Expected argument 'apply_lag' to be a str")
        pulumi.set(__self__, "apply_lag", apply_lag)
        if apply_rate and not isinstance(apply_rate, str):
            raise TypeError("Expected argument 'apply_rate' to be a str")
        pulumi.set(__self__, "apply_rate", apply_rate)
        if availability_domain and not isinstance(availability_domain, str):
            raise TypeError("Expected argument 'availability_domain' to be a str")
        pulumi.set(__self__, "availability_domain", availability_domain)
        if backup_network_nsg_ids and not isinstance(backup_network_nsg_ids, list):
            raise TypeError("Expected argument 'backup_network_nsg_ids' to be a list")
        pulumi.set(__self__, "backup_network_nsg_ids", backup_network_nsg_ids)
        if cpu_core_count and not isinstance(cpu_core_count, int):
            raise TypeError("Expected argument 'cpu_core_count' to be a int")
        pulumi.set(__self__, "cpu_core_count", cpu_core_count)
        if create_async and not isinstance(create_async, bool):
            raise TypeError("Expected argument 'create_async' to be a bool")
        pulumi.set(__self__, "create_async", create_async)
        if creation_type and not isinstance(creation_type, str):
            raise TypeError("Expected argument 'creation_type' to be a str")
        pulumi.set(__self__, "creation_type", creation_type)
        if data_collection_options and not isinstance(data_collection_options, list):
            raise TypeError("Expected argument 'data_collection_options' to be a list")
        pulumi.set(__self__, "data_collection_options", data_collection_options)
        if data_guard_association_id and not isinstance(data_guard_association_id, str):
            raise TypeError("Expected argument 'data_guard_association_id' to be a str")
        pulumi.set(__self__, "data_guard_association_id", data_guard_association_id)
        if database_admin_password and not isinstance(database_admin_password, str):
            raise TypeError("Expected argument 'database_admin_password' to be a str")
        pulumi.set(__self__, "database_admin_password", database_admin_password)
        if database_defined_tags and not isinstance(database_defined_tags, dict):
            raise TypeError("Expected argument 'database_defined_tags' to be a dict")
        pulumi.set(__self__, "database_defined_tags", database_defined_tags)
        if database_freeform_tags and not isinstance(database_freeform_tags, dict):
            raise TypeError("Expected argument 'database_freeform_tags' to be a dict")
        pulumi.set(__self__, "database_freeform_tags", database_freeform_tags)
        if database_id and not isinstance(database_id, str):
            raise TypeError("Expected argument 'database_id' to be a str")
        pulumi.set(__self__, "database_id", database_id)
        if database_software_image_id and not isinstance(database_software_image_id, str):
            raise TypeError("Expected argument 'database_software_image_id' to be a str")
        pulumi.set(__self__, "database_software_image_id", database_software_image_id)
        if db_system_defined_tags and not isinstance(db_system_defined_tags, dict):
            raise TypeError("Expected argument 'db_system_defined_tags' to be a dict")
        pulumi.set(__self__, "db_system_defined_tags", db_system_defined_tags)
        if db_system_freeform_tags and not isinstance(db_system_freeform_tags, dict):
            raise TypeError("Expected argument 'db_system_freeform_tags' to be a dict")
        pulumi.set(__self__, "db_system_freeform_tags", db_system_freeform_tags)
        if delete_standby_db_home_on_delete and not isinstance(delete_standby_db_home_on_delete, str):
            raise TypeError("Expected argument 'delete_standby_db_home_on_delete' to be a str")
        pulumi.set(__self__, "delete_standby_db_home_on_delete", delete_standby_db_home_on_delete)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if fault_domains and not isinstance(fault_domains, list):
            raise TypeError("Expected argument 'fault_domains' to be a list")
        pulumi.set(__self__, "fault_domains", fault_domains)
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_active_data_guard_enabled and not isinstance(is_active_data_guard_enabled, bool):
            raise TypeError("Expected argument 'is_active_data_guard_enabled' to be a bool")
        pulumi.set(__self__, "is_active_data_guard_enabled", is_active_data_guard_enabled)
        if license_model and not isinstance(license_model, str):
            raise TypeError("Expected argument 'license_model' to be a str")
        pulumi.set(__self__, "license_model", license_model)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if node_count and not isinstance(node_count, int):
            raise TypeError("Expected argument 'node_count' to be a int")
        pulumi.set(__self__, "node_count", node_count)
        if nsg_ids and not isinstance(nsg_ids, list):
            raise TypeError("Expected argument 'nsg_ids' to be a list")
        pulumi.set(__self__, "nsg_ids", nsg_ids)
        if peer_data_guard_association_id and not isinstance(peer_data_guard_association_id, str):
            raise TypeError("Expected argument 'peer_data_guard_association_id' to be a str")
        pulumi.set(__self__, "peer_data_guard_association_id", peer_data_guard_association_id)
        if peer_database_id and not isinstance(peer_database_id, str):
            raise TypeError("Expected argument 'peer_database_id' to be a str")
        pulumi.set(__self__, "peer_database_id", peer_database_id)
        if peer_db_home_id and not isinstance(peer_db_home_id, str):
            raise TypeError("Expected argument 'peer_db_home_id' to be a str")
        pulumi.set(__self__, "peer_db_home_id", peer_db_home_id)
        if peer_db_system_id and not isinstance(peer_db_system_id, str):
            raise TypeError("Expected argument 'peer_db_system_id' to be a str")
        pulumi.set(__self__, "peer_db_system_id", peer_db_system_id)
        if peer_db_unique_name and not isinstance(peer_db_unique_name, str):
            raise TypeError("Expected argument 'peer_db_unique_name' to be a str")
        pulumi.set(__self__, "peer_db_unique_name", peer_db_unique_name)
        if peer_role and not isinstance(peer_role, str):
            raise TypeError("Expected argument 'peer_role' to be a str")
        pulumi.set(__self__, "peer_role", peer_role)
        if peer_sid_prefix and not isinstance(peer_sid_prefix, str):
            raise TypeError("Expected argument 'peer_sid_prefix' to be a str")
        pulumi.set(__self__, "peer_sid_prefix", peer_sid_prefix)
        if peer_vm_cluster_id and not isinstance(peer_vm_cluster_id, str):
            raise TypeError("Expected argument 'peer_vm_cluster_id' to be a str")
        pulumi.set(__self__, "peer_vm_cluster_id", peer_vm_cluster_id)
        if private_ip and not isinstance(private_ip, str):
            raise TypeError("Expected argument 'private_ip' to be a str")
        pulumi.set(__self__, "private_ip", private_ip)
        if protection_mode and not isinstance(protection_mode, str):
            raise TypeError("Expected argument 'protection_mode' to be a str")
        pulumi.set(__self__, "protection_mode", protection_mode)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)
        if shape and not isinstance(shape, str):
            raise TypeError("Expected argument 'shape' to be a str")
        pulumi.set(__self__, "shape", shape)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if storage_volume_performance_mode and not isinstance(storage_volume_performance_mode, str):
            raise TypeError("Expected argument 'storage_volume_performance_mode' to be a str")
        pulumi.set(__self__, "storage_volume_performance_mode", storage_volume_performance_mode)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_zone and not isinstance(time_zone, str):
            raise TypeError("Expected argument 'time_zone' to be a str")
        pulumi.set(__self__, "time_zone", time_zone)
        if transport_type and not isinstance(transport_type, str):
            raise TypeError("Expected argument 'transport_type' to be a str")
        pulumi.set(__self__, "transport_type", transport_type)

    @property
    @pulumi.getter(name="applyLag")
    def apply_lag(self) -> str:
        """
        The lag time between updates to the primary database and application of the redo data on the standby database, as computed by the reporting database.  Example: `9 seconds`
        """
        return pulumi.get(self, "apply_lag")

    @property
    @pulumi.getter(name="applyRate")
    def apply_rate(self) -> str:
        """
        The rate at which redo logs are synced between the associated databases.  Example: `180 Mb per second`
        """
        return pulumi.get(self, "apply_rate")

    @property
    @pulumi.getter(name="availabilityDomain")
    def availability_domain(self) -> str:
        return pulumi.get(self, "availability_domain")

    @property
    @pulumi.getter(name="backupNetworkNsgIds")
    def backup_network_nsg_ids(self) -> Sequence[str]:
        return pulumi.get(self, "backup_network_nsg_ids")

    @property
    @pulumi.getter(name="cpuCoreCount")
    def cpu_core_count(self) -> int:
        return pulumi.get(self, "cpu_core_count")

    @property
    @pulumi.getter(name="createAsync")
    def create_async(self) -> bool:
        return pulumi.get(self, "create_async")

    @property
    @pulumi.getter(name="creationType")
    def creation_type(self) -> str:
        return pulumi.get(self, "creation_type")

    @property
    @pulumi.getter(name="dataCollectionOptions")
    def data_collection_options(self) -> Sequence['outputs.GetDataGuardAssociationDataCollectionOptionResult']:
        return pulumi.get(self, "data_collection_options")

    @property
    @pulumi.getter(name="dataGuardAssociationId")
    def data_guard_association_id(self) -> str:
        return pulumi.get(self, "data_guard_association_id")

    @property
    @pulumi.getter(name="databaseAdminPassword")
    def database_admin_password(self) -> str:
        return pulumi.get(self, "database_admin_password")

    @property
    @pulumi.getter(name="databaseDefinedTags")
    def database_defined_tags(self) -> Mapping[str, Any]:
        return pulumi.get(self, "database_defined_tags")

    @property
    @pulumi.getter(name="databaseFreeformTags")
    def database_freeform_tags(self) -> Mapping[str, Any]:
        return pulumi.get(self, "database_freeform_tags")

    @property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the reporting database.
        """
        return pulumi.get(self, "database_id")

    @property
    @pulumi.getter(name="databaseSoftwareImageId")
    def database_software_image_id(self) -> str:
        return pulumi.get(self, "database_software_image_id")

    @property
    @pulumi.getter(name="dbSystemDefinedTags")
    def db_system_defined_tags(self) -> Mapping[str, Any]:
        return pulumi.get(self, "db_system_defined_tags")

    @property
    @pulumi.getter(name="dbSystemFreeformTags")
    def db_system_freeform_tags(self) -> Mapping[str, Any]:
        return pulumi.get(self, "db_system_freeform_tags")

    @property
    @pulumi.getter(name="deleteStandbyDbHomeOnDelete")
    def delete_standby_db_home_on_delete(self) -> str:
        return pulumi.get(self, "delete_standby_db_home_on_delete")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="faultDomains")
    def fault_domains(self) -> Sequence[str]:
        return pulumi.get(self, "fault_domains")

    @property
    @pulumi.getter
    def hostname(self) -> str:
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Data Guard association.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isActiveDataGuardEnabled")
    def is_active_data_guard_enabled(self) -> bool:
        """
        True if active Data Guard is enabled.
        """
        return pulumi.get(self, "is_active_data_guard_enabled")

    @property
    @pulumi.getter(name="licenseModel")
    def license_model(self) -> str:
        return pulumi.get(self, "license_model")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        Additional information about the current lifecycleState, if available.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> int:
        return pulumi.get(self, "node_count")

    @property
    @pulumi.getter(name="nsgIds")
    def nsg_ids(self) -> Sequence[str]:
        return pulumi.get(self, "nsg_ids")

    @property
    @pulumi.getter(name="peerDataGuardAssociationId")
    def peer_data_guard_association_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the peer database's Data Guard association.
        """
        return pulumi.get(self, "peer_data_guard_association_id")

    @property
    @pulumi.getter(name="peerDatabaseId")
    def peer_database_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the associated peer database.
        """
        return pulumi.get(self, "peer_database_id")

    @property
    @pulumi.getter(name="peerDbHomeId")
    def peer_db_home_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Database Home containing the associated peer database.
        """
        return pulumi.get(self, "peer_db_home_id")

    @property
    @pulumi.getter(name="peerDbSystemId")
    def peer_db_system_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DB system containing the associated peer database.
        """
        return pulumi.get(self, "peer_db_system_id")

    @property
    @pulumi.getter(name="peerDbUniqueName")
    def peer_db_unique_name(self) -> str:
        return pulumi.get(self, "peer_db_unique_name")

    @property
    @pulumi.getter(name="peerRole")
    def peer_role(self) -> str:
        """
        The role of the peer database in this Data Guard association.
        """
        return pulumi.get(self, "peer_role")

    @property
    @pulumi.getter(name="peerSidPrefix")
    def peer_sid_prefix(self) -> str:
        return pulumi.get(self, "peer_sid_prefix")

    @property
    @pulumi.getter(name="peerVmClusterId")
    def peer_vm_cluster_id(self) -> str:
        return pulumi.get(self, "peer_vm_cluster_id")

    @property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> str:
        return pulumi.get(self, "private_ip")

    @property
    @pulumi.getter(name="protectionMode")
    def protection_mode(self) -> str:
        """
        The protection mode of this Data Guard association. For more information, see [Oracle Data Guard Protection Modes](http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000) in the Oracle Data Guard documentation.
        """
        return pulumi.get(self, "protection_mode")

    @property
    @pulumi.getter
    def role(self) -> str:
        """
        The role of the reporting database in this Data Guard association.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter
    def shape(self) -> str:
        return pulumi.get(self, "shape")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the Data Guard association.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="storageVolumePerformanceMode")
    def storage_volume_performance_mode(self) -> str:
        return pulumi.get(self, "storage_volume_performance_mode")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the Data Guard association was created.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> str:
        return pulumi.get(self, "time_zone")

    @property
    @pulumi.getter(name="transportType")
    def transport_type(self) -> str:
        """
        The redo transport type used by this Data Guard association.  For more information, see [Redo Transport Services](http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400) in the Oracle Data Guard documentation.
        """
        return pulumi.get(self, "transport_type")


class AwaitableGetDataGuardAssociationResult(GetDataGuardAssociationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataGuardAssociationResult(
            apply_lag=self.apply_lag,
            apply_rate=self.apply_rate,
            availability_domain=self.availability_domain,
            backup_network_nsg_ids=self.backup_network_nsg_ids,
            cpu_core_count=self.cpu_core_count,
            create_async=self.create_async,
            creation_type=self.creation_type,
            data_collection_options=self.data_collection_options,
            data_guard_association_id=self.data_guard_association_id,
            database_admin_password=self.database_admin_password,
            database_defined_tags=self.database_defined_tags,
            database_freeform_tags=self.database_freeform_tags,
            database_id=self.database_id,
            database_software_image_id=self.database_software_image_id,
            db_system_defined_tags=self.db_system_defined_tags,
            db_system_freeform_tags=self.db_system_freeform_tags,
            delete_standby_db_home_on_delete=self.delete_standby_db_home_on_delete,
            display_name=self.display_name,
            fault_domains=self.fault_domains,
            hostname=self.hostname,
            id=self.id,
            is_active_data_guard_enabled=self.is_active_data_guard_enabled,
            license_model=self.license_model,
            lifecycle_details=self.lifecycle_details,
            node_count=self.node_count,
            nsg_ids=self.nsg_ids,
            peer_data_guard_association_id=self.peer_data_guard_association_id,
            peer_database_id=self.peer_database_id,
            peer_db_home_id=self.peer_db_home_id,
            peer_db_system_id=self.peer_db_system_id,
            peer_db_unique_name=self.peer_db_unique_name,
            peer_role=self.peer_role,
            peer_sid_prefix=self.peer_sid_prefix,
            peer_vm_cluster_id=self.peer_vm_cluster_id,
            private_ip=self.private_ip,
            protection_mode=self.protection_mode,
            role=self.role,
            shape=self.shape,
            state=self.state,
            storage_volume_performance_mode=self.storage_volume_performance_mode,
            subnet_id=self.subnet_id,
            time_created=self.time_created,
            time_zone=self.time_zone,
            transport_type=self.transport_type)


def get_data_guard_association(data_guard_association_id: Optional[str] = None,
                               database_id: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataGuardAssociationResult:
    """
    This data source provides details about a specific Data Guard Association resource in Oracle Cloud Infrastructure Database service.

    Gets the specified Data Guard association's configuration information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_data_guard_association = oci.Database.get_data_guard_association(data_guard_association_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str data_guard_association_id: The Data Guard association's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str database_id: The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    __args__ = dict()
    __args__['dataGuardAssociationId'] = data_guard_association_id
    __args__['databaseId'] = database_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getDataGuardAssociation:getDataGuardAssociation', __args__, opts=opts, typ=GetDataGuardAssociationResult).value

    return AwaitableGetDataGuardAssociationResult(
        apply_lag=__ret__.apply_lag,
        apply_rate=__ret__.apply_rate,
        availability_domain=__ret__.availability_domain,
        backup_network_nsg_ids=__ret__.backup_network_nsg_ids,
        cpu_core_count=__ret__.cpu_core_count,
        create_async=__ret__.create_async,
        creation_type=__ret__.creation_type,
        data_collection_options=__ret__.data_collection_options,
        data_guard_association_id=__ret__.data_guard_association_id,
        database_admin_password=__ret__.database_admin_password,
        database_defined_tags=__ret__.database_defined_tags,
        database_freeform_tags=__ret__.database_freeform_tags,
        database_id=__ret__.database_id,
        database_software_image_id=__ret__.database_software_image_id,
        db_system_defined_tags=__ret__.db_system_defined_tags,
        db_system_freeform_tags=__ret__.db_system_freeform_tags,
        delete_standby_db_home_on_delete=__ret__.delete_standby_db_home_on_delete,
        display_name=__ret__.display_name,
        fault_domains=__ret__.fault_domains,
        hostname=__ret__.hostname,
        id=__ret__.id,
        is_active_data_guard_enabled=__ret__.is_active_data_guard_enabled,
        license_model=__ret__.license_model,
        lifecycle_details=__ret__.lifecycle_details,
        node_count=__ret__.node_count,
        nsg_ids=__ret__.nsg_ids,
        peer_data_guard_association_id=__ret__.peer_data_guard_association_id,
        peer_database_id=__ret__.peer_database_id,
        peer_db_home_id=__ret__.peer_db_home_id,
        peer_db_system_id=__ret__.peer_db_system_id,
        peer_db_unique_name=__ret__.peer_db_unique_name,
        peer_role=__ret__.peer_role,
        peer_sid_prefix=__ret__.peer_sid_prefix,
        peer_vm_cluster_id=__ret__.peer_vm_cluster_id,
        private_ip=__ret__.private_ip,
        protection_mode=__ret__.protection_mode,
        role=__ret__.role,
        shape=__ret__.shape,
        state=__ret__.state,
        storage_volume_performance_mode=__ret__.storage_volume_performance_mode,
        subnet_id=__ret__.subnet_id,
        time_created=__ret__.time_created,
        time_zone=__ret__.time_zone,
        transport_type=__ret__.transport_type)


@_utilities.lift_output_func(get_data_guard_association)
def get_data_guard_association_output(data_guard_association_id: Optional[pulumi.Input[str]] = None,
                                      database_id: Optional[pulumi.Input[str]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDataGuardAssociationResult]:
    """
    This data source provides details about a specific Data Guard Association resource in Oracle Cloud Infrastructure Database service.

    Gets the specified Data Guard association's configuration information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_data_guard_association = oci.Database.get_data_guard_association(data_guard_association_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str data_guard_association_id: The Data Guard association's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str database_id: The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDbSystemsUpgradeHistoryEntriesResult',
    'AwaitableGetDbSystemsUpgradeHistoryEntriesResult',
    'get_db_systems_upgrade_history_entries',
    'get_db_systems_upgrade_history_entries_output',
]

@pulumi.output_type
class GetDbSystemsUpgradeHistoryEntriesResult:
    """
    A collection of values returned by getDbSystemsUpgradeHistoryEntries.
    """
    def __init__(__self__, db_system_id=None, db_system_upgrade_history_entries=None, filters=None, id=None, state=None, upgrade_action=None):
        if db_system_id and not isinstance(db_system_id, str):
            raise TypeError("Expected argument 'db_system_id' to be a str")
        pulumi.set(__self__, "db_system_id", db_system_id)
        if db_system_upgrade_history_entries and not isinstance(db_system_upgrade_history_entries, list):
            raise TypeError("Expected argument 'db_system_upgrade_history_entries' to be a list")
        pulumi.set(__self__, "db_system_upgrade_history_entries", db_system_upgrade_history_entries)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if upgrade_action and not isinstance(upgrade_action, str):
            raise TypeError("Expected argument 'upgrade_action' to be a str")
        pulumi.set(__self__, "upgrade_action", upgrade_action)

    @property
    @pulumi.getter(name="dbSystemId")
    def db_system_id(self) -> str:
        return pulumi.get(self, "db_system_id")

    @property
    @pulumi.getter(name="dbSystemUpgradeHistoryEntries")
    def db_system_upgrade_history_entries(self) -> Sequence['outputs.GetDbSystemsUpgradeHistoryEntriesDbSystemUpgradeHistoryEntryResult']:
        """
        The list of db_system_upgrade_history_entries.
        """
        return pulumi.get(self, "db_system_upgrade_history_entries")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetDbSystemsUpgradeHistoryEntriesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the action.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="upgradeAction")
    def upgrade_action(self) -> Optional[str]:
        return pulumi.get(self, "upgrade_action")


class AwaitableGetDbSystemsUpgradeHistoryEntriesResult(GetDbSystemsUpgradeHistoryEntriesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDbSystemsUpgradeHistoryEntriesResult(
            db_system_id=self.db_system_id,
            db_system_upgrade_history_entries=self.db_system_upgrade_history_entries,
            filters=self.filters,
            id=self.id,
            state=self.state,
            upgrade_action=self.upgrade_action)


def get_db_systems_upgrade_history_entries(db_system_id: Optional[str] = None,
                                           filters: Optional[Sequence[pulumi.InputType['GetDbSystemsUpgradeHistoryEntriesFilterArgs']]] = None,
                                           state: Optional[str] = None,
                                           upgrade_action: Optional[str] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDbSystemsUpgradeHistoryEntriesResult:
    """
    This data source provides the list of Db Systems Upgrade History Entries in Oracle Cloud Infrastructure Database service.

    Gets the history of the upgrade actions performed on the specified DB system.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_db_systems_upgrade_history_entries = oci.Database.get_db_systems_upgrade_history_entries(db_system_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        upgrade_action=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str db_system_id: The DB system [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str state: A filter to return only upgrade history entries that match the given lifecycle state exactly.
    :param str upgrade_action: A filter to return only upgradeHistoryEntries that match the specified Upgrade Action.
    """
    __args__ = dict()
    __args__['dbSystemId'] = db_system_id
    __args__['filters'] = filters
    __args__['state'] = state
    __args__['upgradeAction'] = upgrade_action
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getDbSystemsUpgradeHistoryEntries:getDbSystemsUpgradeHistoryEntries', __args__, opts=opts, typ=GetDbSystemsUpgradeHistoryEntriesResult).value

    return AwaitableGetDbSystemsUpgradeHistoryEntriesResult(
        db_system_id=__ret__.db_system_id,
        db_system_upgrade_history_entries=__ret__.db_system_upgrade_history_entries,
        filters=__ret__.filters,
        id=__ret__.id,
        state=__ret__.state,
        upgrade_action=__ret__.upgrade_action)


@_utilities.lift_output_func(get_db_systems_upgrade_history_entries)
def get_db_systems_upgrade_history_entries_output(db_system_id: Optional[pulumi.Input[str]] = None,
                                                  filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDbSystemsUpgradeHistoryEntriesFilterArgs']]]]] = None,
                                                  state: Optional[pulumi.Input[Optional[str]]] = None,
                                                  upgrade_action: Optional[pulumi.Input[Optional[str]]] = None,
                                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDbSystemsUpgradeHistoryEntriesResult]:
    """
    This data source provides the list of Db Systems Upgrade History Entries in Oracle Cloud Infrastructure Database service.

    Gets the history of the upgrade actions performed on the specified DB system.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_db_systems_upgrade_history_entries = oci.Database.get_db_systems_upgrade_history_entries(db_system_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        upgrade_action=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str db_system_id: The DB system [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str state: A filter to return only upgrade history entries that match the given lifecycle state exactly.
    :param str upgrade_action: A filter to return only upgradeHistoryEntries that match the specified Upgrade Action.
    """
    ...
